@@ -536,10 +536,9 @@ OC.L10N.register(
     "Share this link to invite others!" : "Rannit al liamm-mañ gant ar re all !",
     "Conversation link copied to clipboard." : "Liamm diviz eilet er golver",
     "The link could not be copied." : "Ne oa ket posupl eilañ al liamm.",
+    "Dismiss" : "Arrest",
     "Show your screen" : "Diskouez ar skramm",
     "Stop screensharing" : "Echuañ ar rannadenn skramm",
-    "Settings" : "Arventennoù",
-    "Dismiss" : "Arrest",
     "No audio" : "Audio ebet",
     "Mute audio" : "Lac'hañ a audio",
     "Unmute audio" : "Lakaat an odio en dro",
@@ -562,6 +561,7 @@ OC.L10N.register(
     "Disable screenshare" : "Rannañ skramm disaotreet",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hll ket marteze ar re all komprenn ac'hanaoc'h. La'hit ar video evit gwelaat an traoù.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ho kenstagadenn onternet pe ho urzhiataer a labour ha marteze ne c'hell ket ar re all komprenn ac'hanoc'h.",
+    "Grid view" : "Diskwell ar roued",
     "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
     "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
@@ -661,8 +661,8 @@ OC.L10N.register(
     "Add groups or circles" : "Ouhzpennañ strolladoù pe kelc'hioù",
     "Add other sources" : "Ouzhpennañ dre un orin all",
     "Participants" : "Tud",
-    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Chat" : "Chat",
+    "Settings" : "Arventennoù",
     "Display name: " : "Anv tra :",
     "Attachments folder" : "Teuliad stag",
     "Search" : "Klask",
@@ -674,7 +674,6 @@ OC.L10N.register(
     "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
     "Rename conversation" : "Adenvel an diviz",
     "Mute others" : "Lakaat ar re all mut",
-    "Grid view" : "Diskwell ar roued",
     "Send" : "Kas",
     "Add more files" : "Ouzhpennañ muioc'h a restroù",
     "No unread mentions" : "Kemenadenn nan-lennet ebet",
@@ -695,6 +694,7 @@ OC.L10N.register(
     "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
     "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
     "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
+    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
     "Do not disturb" : "Na rannit ket",
     "Away" : "Pell",
@@ -733,18 +733,10 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
     "Android app" : "Meziant Android",
     "iOS app" : "Meziant iOS",
-    "New in Talk 6" : "Nevez e Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- N'eo ket posupl lakaat un diviz unan-hag-unan en un diviz a stroll dre fazi kenn. Pa vez laosket an diviz gant una bennak, n'eo ket lemet an diviz en un doare otomatek kenn. N'eo lemet an diviz eus ar servijour nemet ma vez laosket gant tout an dud.",
-    "New in Talk 7" : "Nevez e Talk 7",
-    "New in Talk 8" : "Nevez e Talk 8",
-    "New in Talk 9" : "Nevez e Talk 9",
-    "{user} wants to talk with you" : "{user} en dus c'hoant da gomz deoc'h",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Implijourien na c'hellont ket impij Talk ken a vo laosket e rollioù en divizoù lec'h m'ho deus kemeret perzh ho gwarnet a vo ho gemenadennoù.",
     "E-mail of the user" : "Postel an implijer",
     "Error: Can not connect to server" : "Fazi : N'eo ket posupl kenstaga ar servijour",
-    "UDP and TCP" : "UDP ha TCP",
-    "UDP only" : "UDP nemetken",
-    "TCP only" : "TCP nemetken",
     "Share whole screen" : "Ranna tout ar skramm",
     "Share a single window" : "Rannañ ur prenestr nemetken",
     "Mute audio (m)" : "Lac'hañ a audio (m)",
@@ -754,8 +746,6 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro (v) -Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
     "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha implijourienn all c'hell gwellet ac'hanoc'h. Evit gwelaat ar stad klaskit disaotreañ ar video pa rit ur rannadenn skramm.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hell marteze ket  ar re all komprenn ac'hanoc'h ha gwellet ho skramm. Evit gwellat ar stad e vefe gwelloc'h lac'han ar rannañ skramm.",
-    "This conversation is read only" : "An diviz a zo da lenn-nemetken",
-    "Conversation, " : "Diviz,",
     "Chat notifications" : "Kemenadennoù chat",
     "Allow guests to join via link " : "Aotreaén ar c'houvidi da don dre liamm",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Ho gortoz er sal gortoz emaoc'h. Ne grog an diviz nemet da {startTime}",
@@ -763,13 +753,7 @@ OC.L10N.register(
     "Camera" : "Kamera",
     "Remove" : "Lemel",
     "[Unknown username]" : "[Anv implijer dianv]",
-    "Enabled" : "Aotreet",
-    "Participant settings" : "Arventennoù tud",
-    "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
-    "Share link" : "Rannan liamm",
     "Exit fullscreen (f)" : "Kuitaat ar skramm a bez (f)",
-    "Fullscreen (f)" : "Skramm a bez (f)",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "N'eo ket douget pen-da-benn ho furcher gant Nextcloud Talk. Implijit kentec'h stum divezhañ Mozilla Firefox, Microsoft Edge, Google Chrome pe Apple Safari.",
-    "Error while uploading file" : "Ur fazi a zo bet en ur pellkas ar restr"
+    "Fullscreen (f)" : "Skramm a bez (f)"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
