@@ -284,10 +284,9 @@ OC.L10N.register(
     "Share this link to invite others!" : "Del dette link for at invitere andre!",
     "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
     "The link could not be copied." : "Linket kunne ikke kopieres.",
+    "Dismiss" : "Afvis",
     "Show your screen" : "Vis din skærm",
     "Stop screensharing" : "Stop skærmdeling",
-    "Settings" : "Indstillinger",
-    "Dismiss" : "Afvis",
     "No audio" : "Ingen lyd",
     "Mute audio" : "Slå lyden fra",
     "No camera" : "Intet kamera",
@@ -295,6 +294,7 @@ OC.L10N.register(
     "Enable video" : "Slå video til",
     "Screensharing options" : "Skærmdeling indstillinger",
     "Enable screensharing" : "Slå skærmdeling til",
+    "Grid view" : "Grid visning",
     "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
@@ -377,15 +377,14 @@ OC.L10N.register(
     "Add groups or circles" : "Tilføj grupper eller cirkler",
     "Add other sources" : "Tilføj andre kilder",
     "Participants" : "Deltagere",
-    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Chat" : "Chat",
+    "Settings" : "Indstillinger",
     "Display name: " : "Vist navn:",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Search" : "Søg",
     "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
     "Start call" : "Start opkald",
     "Rename conversation" : "Omdøb samtale",
-    "Grid view" : "Grid visning",
     "Send" : "Send",
     "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
     "Start a conversation" : "Start en samtale",
@@ -397,6 +396,7 @@ OC.L10N.register(
     "Select conversation" : "Vælg samtale",
     "Link to a conversation" : "Link til samtale",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
+    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Error while sharing file" : "Fejl ved deling af fil",
     "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked",
     "Default" : "Standard",
@@ -419,15 +419,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "New in Talk 6" : "Nyt i Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke laves til gruppesamtaler ved en fejl længere. Derudover bliver samtaler ikke længere slettet automatisk når en af deltagerne forlader den. Samtalen slettes kun fra serveren hvis begge deltagere har forladt den",
-    "New in Talk 7" : "Nyt i Talk 7",
-    "New in Talk 8" : "Nyt i Talk 8",
-    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Brugere som ikke længere kan bruge Talk vil stadig fremgå som deltagere i tidligere samtaler de har deltaget i, og deres chat-beskeder vil blive gemt.",
-    "UDP and TCP" : "UDP og TCP",
-    "UDP only" : "kun UDP",
-    "TCP only" : "kun TCP",
     "Share whole screen" : "Del hele skærmen",
     "Share a single window" : "Del et vindue",
     "Mute audio (m)" : "Slå lyden fra (m)",
@@ -435,18 +428,13 @@ OC.L10N.register(
     "Disable video (v)" : "Slå video fra (v)",
     "Enable video (v)" : "Slå video til (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video (v) - Forbindelsen forsvinder et øjeblik første gang du slår video til",
-    "This conversation is read only" : "Denne samtale er skrivebeskyttet",
     "Chat notifications" : "Chat-notifikationer",
     "Allow guests to join via link " : "Tillad gæster at deltage via link",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
     "Camera" : "Kamera",
     "Remove" : "Fjern",
     "[Unknown username]" : "[Ukendt brugernavn]",
-    "Enabled" : "Aktiveret",
-    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
-    "Share link" : "Del link",
     "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
-    "Fullscreen (f)" : "Vis i fuldskærm (f)",
-    "Error while uploading file" : "Fejl ved upload af fil"
+    "Fullscreen (f)" : "Vis i fuldskærm (f)"
 },
 "nplurals=2; plural=(n != 1);");
