@@ -17,6 +17,7 @@ OC.L10N.register(
     "Talk updates ✅" : "Talk-päivitykset ✅",
     "{actor} created the conversation" : "{actor} loi keskustelun",
     "You created the conversation" : "Sinä loit keskustelun",
+    "An administrator created the conversation" : "Ylläpitäjä loi keskustelun",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sinä muutit keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
     "{actor} set the description" : "{actor} asetti kuvauksen",
@@ -42,6 +43,7 @@ OC.L10N.register(
     "You opened the conversation to everyone" : "Avasit uuden keskustelun kaikille",
     "{actor} allowed guests" : "{actor} salli vieraat",
     "You allowed guests" : "Sinä sallit vieraat",
+    "An administrator allowed guests" : "Ylläpitäjä salli vieraat",
     "{actor} disallowed guests" : "{actor} esti vieraat",
     "You disallowed guests" : "Sinä estit vieraat",
     "{actor} set a password" : "{actor} asetti salasanan",
@@ -56,6 +58,7 @@ OC.L10N.register(
     "You added {user}" : "Sinä lisäsit käyttäjän {user}",
     "{actor} added you" : "{actor} lisäsi sinut",
     "An administrator added you" : "Ylläpitäjä lisäsi sinut",
+    "An administrator added {user}" : "Ylläpitäjä lisäsi käyttäjän {user}",
     "You left the conversation" : "Poistuit keskustelusta",
     "{actor} left the conversation" : "{actor} poistui keskustelusta",
     "{actor} removed {user}" : "{actor} poisti käyttäjän {user}",
@@ -87,6 +90,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
     "File is too big" : "Tiedosto on liian suuri",
+    "Invalid image" : "Virheellinen kuva",
     "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "Write to conversation" : "Kirjoita keskusteluun",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
@@ -231,6 +235,7 @@ OC.L10N.register(
     "Delete this server" : "Poista tämä palvelin",
     "Status: Checking connection" : "Tila: Tarkistetaan yhteyttä",
     "OK: Running version: {version}" : "OK: Suoritetaan versiota: {version}",
+    "Error: Cannot connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
     "Error: Unknown error occurred" : "Virhe: Tuntematon virhe",
     "Saved" : "Tallennettu",
     "Add a new server" : "Lisää uusi palvelin",
@@ -247,10 +252,10 @@ OC.L10N.register(
     "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
     "Conversation link copied to clipboard." : "Keskustelulinkki kopioitu leikepöydälle.",
     "The link could not be copied." : "Linkkiä ei voitu kopioida.",
+    "Dismiss" : "Hylkää",
     "Show your screen" : "Näytä oma näyttösi",
     "Stop screensharing" : "Lopeta näytön jakaminen",
-    "Settings" : "Asetukset",
-    "Dismiss" : "Hylkää",
+    "Blur background" : "Sumenna tausta",
     "No audio" : "Ei ääntä",
     "Mute audio" : "Mykistä ääni",
     "No camera" : "Ei kameraa",
@@ -258,6 +263,7 @@ OC.L10N.register(
     "Enable video" : "Käytä videota",
     "Screensharing options" : "Näytönjakamisen valinnat",
     "Enable screensharing" : "Ota käyttöön näytönjakaminen",
+    "Grid view" : "Ruudukkonäkymä",
     "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
@@ -276,15 +282,18 @@ OC.L10N.register(
     "Conversation settings" : "Keskustelun asetukset",
     "Description" : "Kuvaus",
     "Enter a description for this conversation" : "Anna kuvaus tälle keskustelulle",
+    "Notifications" : "Ilmoitukset",
     "Meeting settings" : "Kokouksen asetukset",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
+    "Allow guests" : "Salli vieraat",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
     "Save password" : "Tallenna salasana",
     "Copy conversation link" : "Kopioi keskustelulinkki",
     "Resend invitations" : "Lähetä kutsut uudelleen",
+    "Invitations sent" : "Kutsut lähetetty",
     "Error occurred when sending invitations" : "Kutsujen lähetyksessä tapahtui virhe",
     "Enable lobby" : "Käytä aulaa",
     "Start time (optional)" : "Aloitusaika (valinnainen)",
@@ -295,6 +304,7 @@ OC.L10N.register(
     "More information" : "Lisää tietoa",
     "Delete" : "Poista",
     "Nextcloud user" : "Nextcloud-käyttäjä",
+    "Matrix server URL" : "Matrix-palvelimen URL-osoite",
     "Matrix channel" : "Matrix-kanava",
     "Mattermost user" : "Mattermost-käyttäjä",
     "Channel name" : "Kanavan nimi",
@@ -319,6 +329,8 @@ OC.L10N.register(
     "Add to favorites" : "Lisää suosikkeihin",
     "You: {lastMessage}" : "Sinä: {lastMessage}",
     "No matches" : "Ei täsmääviä",
+    "Conversation list" : "Keskustelulista",
+    "Open conversations" : "Avaa keskustelut",
     "Loading" : "Ladataan",
     "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
@@ -342,6 +354,7 @@ OC.L10N.register(
     "Conversation name" : "Keskustelun nimi",
     "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
+    "The meeting will start soon" : "Tämä kokous alkaa pian",
     "No microphone available" : "Ei mikrofonia saatavilla",
     "Select microphone" : "Valitse mikrofoni",
     "No camera available" : "Ei kameraa saatavilla",
@@ -368,8 +381,12 @@ OC.L10N.register(
     "Add emoji" : "Lisää emoji",
     "Send message" : "Lähetä viesti",
     "File to share" : "Jaettava tiedosto",
+    "This conversation has been locked" : "Tämä keskustelu on lukittu",
     "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
     "Invalid path selected" : "Valittu virheellinen polku",
+    "Start a call" : "Aloita puhelu",
+    "Share the screen" : "Jaa näyttö",
+    "Update permissions" : "Päivitä oikeudet",
     "moderator" : "moderaattori",
     "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
@@ -389,6 +406,7 @@ OC.L10N.register(
     "Participants" : "Osallistujat",
     "Search or add participants" : "Etsi tai lisää osallistujia",
     "Chat" : "Keskustelu",
+    "Settings" : "Asetukset",
     "Display name: " : "Näyttönimi:",
     "Attachments folder" : "Liitteiden kansio",
     "Privacy" : "Yksityisyys",
@@ -401,7 +419,8 @@ OC.L10N.register(
     "Toggle fullscreen" : "Koko näyttö päälle/pois",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
     "Mute others" : "Mykistä muut",
-    "Grid view" : "Ruudukkonäkymä",
+    "Exit fullscreen (F)" : "Poistu koko näytön tilasta (F)",
+    "Fullscreen (F)" : "Koko näyttö (F)",
     "Send" : "Lähetä",
     "Add more files" : "Lisää enemmän tiedostoja",
     "No unread mentions" : "Ei lukemattomia mainintoja",
@@ -412,6 +431,7 @@ OC.L10N.register(
     "Mention room" : "Mainitse huone",
     "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
     "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
+    "No conversations found" : "Keskusteluja ei löytynyt",
     "Select conversation" : "Valitse keskustelu",
     "Link to a conversation" : "Linkki keskusteluun",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
@@ -441,39 +461,26 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
-    "New in Talk 6" : "Uutta Talkin 6-versiossa",
-    "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
     "E-mail of the user" : "Käyttäjän sähköpostiosoite",
     "Error: Can not connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
-    "UDP and TCP" : "UDP ja TCP",
-    "UDP only" : "Vain UDP",
-    "TCP only" : "Vain TCP",
     "Share whole screen" : "Jaa koko näyttö",
     "Share a single window" : "Jaa yksittäinen ikkuna",
+    "Lower hand" : "Laske käsi",
+    "Raise hand" : "Nosta käsi",
     "Mute audio (m)" : "Mykistä äänet (m)",
     "Unmute audio (m)" : "Palauta äänet (m)",
     "Disable video (v)" : "Poista video käytöstä (v)",
     "Enable video (v)" : "Ota video käyttöön (v)",
-    "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
+    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
+    "Conversation \"{conversationName}\"" : "Keskustelu \"{conversationName}\"",
+    "Settings for conversation \"{conversationName}\"" : "Asetukset keskustelulle \"{conversationName}\"",
     "Chat notifications" : "Keskusteluilmoitukset",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
     "Microphone" : "Mikrofoni",
     "Camera" : "Kamera",
     "Remove" : "Poista",
-    "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
-    "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
-    "Enabled" : "Käytössä",
-    "Show matterbridge log" : "Näytä matterbridge-loki",
-    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
-    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
-    "Share link" : "Jaa linkki",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
-    "Fullscreen (f)" : "Koko näytön tila (f)",
-    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
-    "Lower hand" : "Laske käsi",
-    "Raise hand" : "Nosta käsi",
-    "Conversation \"{conversationName}\"" : "Keskustelu \"{conversationName}\"",
-    "Settings for conversation \"{conversationName}\"" : "Asetukset keskustelulle \"{conversationName}\""
+    "Fullscreen (f)" : "Koko näytön tila (f)"
 },
 "nplurals=2; plural=(n != 1);");
