@@ -390,16 +390,17 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
+    "Dismiss" : "התעלמות",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
-    "Settings" : "הגדרות",
-    "Dismiss" : "התעלמות",
     "No audio" : "אין שמע",
     "Mute audio" : "השתקת שמע",
     "Disable video" : "השבתת וידאו",
     "Enable video" : "הפעלת וידאו",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
@@ -503,8 +504,8 @@ OC.L10N.register(
     "Add groups or circles" : "הוספת קבוצות או מעגלים",
     "Add other sources" : "הוספת מקורות אחרים",
     "Participants" : "משתתפים",
-    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Chat" : "צ׳אט",
+    "Settings" : "הגדרות",
     "Display name: " : "שם תצוגה:",
     "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Keyboard shortcuts" : "קיצורי מקלדת",
@@ -514,8 +515,6 @@ OC.L10N.register(
     "Start call" : "התחלת שיחה",
     "Rename conversation" : "שינוי שם הדיון",
     "Mute others" : "השתקה של אחרים",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
     "Send" : "שליחה",
     "Add more files" : "הוספת קבצים נוספים",
     "No unread mentions" : "אין אזכורים שלא נקראו",
@@ -530,6 +529,7 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
     "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
+    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "Default" : "בררת מחדל",
     "Speaker {number}" : "רמקול {number}",
@@ -545,31 +545,17 @@ OC.L10N.register(
     "Signaling servers" : "שרתי איתות",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "New in Talk 6" : "חדש ב־Talk 6",
-    "New in Talk 7" : "חדש ב־Talk 7",
-    "New in Talk 8" : "חדש ב־Talk 8",
-    "UDP and TCP" : "UDP ו־TCP",
-    "UDP only" : "UDP בלבד",
-    "TCP only" : "TCP בלבד",
     "Mute audio (m)" : "השתקת שמע (m)",
     "Unmute audio (m)" : "ביטול השקת שמע (m)",
     "Disable video (v)" : "השבתת וידאו (v)",
     "Enable video (v)" : "הפעלת וידאו (v)",
-    "Conversation, " : "דיון,",
+    "User name or e-mail address" : "שם משתמש או כתובת דוא״ל",
     "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
     "Microphone" : "מיקרופון",
     "Camera" : "מצלמה",
     "Remove" : "הסרה",
     "[Unknown username]" : "[שם משתמש לא ידוע]",
-    "Bridge with other services" : "גישור עם שירותים אחרים",
-    "More info on Matterbridge." : "מידע נוסף על Matterbridge.",
-    "Enabled" : "מופעל",
-    "User name or e-mail address" : "שם משתמש או כתובת דוא״ל",
-    "Add new bridged channel" : "הוספת ערוץ מגושר חדש",
-    "Participant settings" : "הגדרות משתתפים",
-    "Add participants to the conversation" : "הוספת משתתפים לדיון",
-    "Share link" : "שיתוף קישור",
     "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
     "Fullscreen (f)" : "מסך מלא (f)"
 },
