@@ -12,6 +12,7 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["dar %n asmuo","dar %n asmenys","dar %n asmenų","dar %n asmuo"],
     "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Jūs buvote pakviesti į <strong>pokalbį</strong> arba jums <strong>skambino</strong>",
+    "Other activities" : "Kitos veiklos",
     "Talk" : "Pokalbiai",
     "Guest" : "Svečias",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Sveiki atvykę į Nextcloud Pokalbius!\nŠiame pokalbyje būsite informuojami apie naujas Nextcloud Pokalbiuose prieinamas ypatybes.",
@@ -80,6 +81,9 @@ OC.L10N.register(
     "You removed {user}" : "Jūs pašalinote naudotoją {user}",
     "{actor} removed you" : "{actor} jus pašalino",
     "An administrator removed {user}" : "Administratorius pašalino naudotoją {user}",
+    "{actor} removed group {group}" : "{actor} pašalino grupę {group}",
+    "You removed group {group}" : "Jūs pašalinote grupę {group}",
+    "An administrator removed group {group}" : "Administratorius pašalino grupę {group}",
     "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
     "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
     "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
@@ -92,10 +96,17 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
     "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
     "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
+    "{actor} updated the Matterbridge configuration" : "{actor} atnaujino „Matterbridge“ konfigūraciją",
+    "You updated the Matterbridge configuration" : "Jūs atnaujinote „Matterbridge“ konfigūraciją",
+    "{actor} removed the Matterbridge configuration" : "{actor} pašalino „Matterbridge“ konfigūraciją",
+    "You removed the Matterbridge configuration" : "Jūs pašalinote „Matterbridge“ konfigūraciją",
     "{actor} deleted a message" : "{actor} ištrynė žinutę",
     "You deleted a message" : "Jūs ištrynėte žinutę",
     "{actor} cleared the history of the conversation" : "{actor} išvalė pokalbio istoriją",
     "You cleared the history of the conversation" : "Jūs išvalėte pokalbio istoriją",
+    "Message deleted by author" : "Autorius ištrynė žinutę",
+    "Message deleted by you" : "Jūs ištrynėte žinutę",
+    "Deleted user" : "Ištrintas naudotojas",
     "%s (guest)" : "%s (svečias)",
     "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
@@ -423,6 +434,9 @@ OC.L10N.register(
     "TURN server protocols" : "TURN serverio protokolai",
     "Test this server" : "Išbandyti šį serverį",
     "TURN servers" : "TURN serveriai",
+    "Failed" : "Nepavyko",
+    "OK" : "Gerai",
+    "Checking …" : "Tikrinama…",
     "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
     "A participant raised their hand." : "Dalyvis pakėlė ranką.",
     "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
@@ -435,12 +449,11 @@ OC.L10N.register(
     "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
     "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
     "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
+    "Dismiss" : "Atmesti",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
     "Lower hand (R)" : "Nuleisti ranką (R)",
     "More actions" : "Daugiau veiksmų",
-    "Settings" : "Nustatymai",
-    "Dismiss" : "Atmesti",
     "Raise hand (R)" : "Pakelti ranką (R)",
     "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
     "No audio" : "Nėra jokio garso",
@@ -458,6 +471,7 @@ OC.L10N.register(
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
     "Disable screenshare" : "Išjungti ekrano bendrinimą",
+    "Grid view" : "Tinklelio rodinys",
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
@@ -467,7 +481,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
     "Back" : "Atgal",
     "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
-    "Error while accessing camera: it is likely in use by another program" : "Klaida gaunant prieigą prie kameros: tikėtina, kad ją naudoja kita programa",
     "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
@@ -604,9 +617,9 @@ OC.L10N.register(
     "Add groups or circles" : "Pridėti grupes ar ratus",
     "Add other sources" : "Pridėti kitus šaltinius",
     "Participants" : "Dalyviai",
-    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
     "Details" : "Išsamiau",
+    "Settings" : "Nustatymai",
     "Meeting ID: {meetingId}" : "Susitikimo ID: {meetingId}",
     "Your PIN: {attendeePin}" : "Jūsų PIN kodas: {attendeePin}",
     "Display name: " : "Rodomas vardas: ",
@@ -616,13 +629,14 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Klavišų kombinacijos",
     "Search" : "Ieškoti",
     "Space bar" : "Tarpas",
+    "Raise or lower hand" : "Pakelti ar nuleisti ranką",
+    "Choose the folder in which attachments should be saved." : "Pasirinkite aplanką į kurį bus įrašomi priedai.",
     "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Start call" : "Pradėti skambutį",
     "Toggle fullscreen" : "Perjungti visą ekraną",
     "Rename conversation" : "Pervadinti pokalbį",
     "Exit fullscreen (F)" : "Išeiti iš viso ekrano (F)",
     "Fullscreen (F)" : "Visas ekranas (F)",
-    "Grid view" : "Tinklelio rodinys",
     "Send" : "Siųsti",
     "Add more files" : "Pridėti daugiau failų",
     "No unread mentions" : "Nėra neskaitytų paminėjimų",
@@ -639,6 +653,7 @@ OC.L10N.register(
     "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
     "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
     "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
+    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
     "Do not disturb" : "Netrukdyti",
     "Away" : "Atsitraukęs",
@@ -669,57 +684,45 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
-    "New in Talk 6" : "Kas naujo Pokalbiuose 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Dabar, pokalbiai vienu du yra išliekantys ir daugiau nebegali būti atsitiktinai paversti į grupės pokalbius. Be to, kai kuris nors vienas dalyvis išeina iš pokalbio, pokalbis daugiau nebėra automatiškai ištrinamas. Tik tuo atveju, jei abu dalyviai išėjo iš pokalbio, pokalbis yra ištrinamas iš serverio",
-    "New in Talk 7" : "Kas naujo Pokalbiuose 7",
-    "New in Talk 8" : "Nauja Pokalbiuose 8",
-    "New in Talk 9" : "Nauja Pokalbiuose 9",
-    "New in Talk 10" : "Nauja Pokalbiuose 10",
+    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
+    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
+    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
     "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} nustatė „Matterbridge“, kad sinchronizuotų šį pokalbį su kitais pokalbiais.",
     "You set up Matterbridge to synchronize this conversation with other chats." : "Jūs nustatėte „Matterbridge“, kad sinchronizuotumėte šį pokalbį su kitais pokalbiais.",
     "{actor} updated the Matterbridge configuration." : "{actor} atnaujino „Matterbridge“ konfigūraciją.",
     "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
     "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
     "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
-    "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
+    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
+    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
+    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
+    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
     "E-mail of the user" : "Naudotojo el. paštas",
     "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
-    "UDP and TCP" : "UDP ir TCP",
-    "UDP only" : "Tik UDP",
-    "TCP only" : "Tik TCP",
     "Share whole screen" : "Bendrinti visą ekraną",
     "Share a single window" : "Bendrinti vieną langą",
+    "Lower hand" : "Nuleisti ranką",
+    "Raise hand" : "Pakelti ranką",
     "Mute audio (m)" : "Nutildyti garsą (m)",
     "Unmute audio (m)" : "Įjungti garsą (m)",
     "Disable video (v)" : "Išjungti vaizdą (v)",
     "Enable video (v)" : "Įjungti vaizdą (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (v) - Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
-    "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
+    "Error while accessing camera: it is likely in use by another program" : "Klaida gaunant prieigą prie kameros: tikėtina, kad ją naudoja kita programa",
+    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
+    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“",
     "Chat notifications" : "Pokalbio pranešimai",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Microphone" : "Mikrofonas",
     "Camera" : "Kamera",
+    "You can not send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
     "Remove" : "Šalinti",
     "[Unknown username]" : "[Nežinomas naudotojo vardas]",
-    "Enabled" : "Įjungta",
-    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
-    "Participant settings" : "Dalyvio nustatymai",
-    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
-    "Share link" : "Bendrinimo nuoroda",
+    "Add a description for this conversation" : "Pridėkite šio pokalbio aprašą",
+    "Choose in which folder attachments should be saved." : "Pasirinkite į kurį aplanką turėtų būti įrašomi priedai.",
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
-    "Fullscreen (f)" : "Visas ekranas (f)",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai nepalaiko pilnai jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
-    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
-    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
-    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
-    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
-    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
-    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
-    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
-    "Lower hand" : "Nuleisti ranką",
-    "Raise hand" : "Pakelti ranką",
-    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“",
-    "You can not send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį"
+    "Fullscreen (f)" : "Visas ekranas (f)"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
