@@ -511,10 +511,9 @@ OC.L10N.register(
     "Share this link to invite others!" : "Споделете ја оваа врска за да поканите други учесници!",
     "Conversation link copied to clipboard." : "Линк до разговорот е копиран во клипборд.",
     "The link could not be copied." : "Линкот неможе да се копира.",
+    "Dismiss" : "Отфрли",
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
-    "Settings" : "Параметри",
-    "Dismiss" : "Отфрли",
     "No audio" : "Нема аудио",
     "Mute audio" : "Занеми (Mute) аудио",
     "Unmute audio" : "Одзанеми (Unmute) го аудиото",
@@ -537,6 +536,8 @@ OC.L10N.register(
     "Disable screenshare" : "Оневозможи споделување на екранот",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат.",
+    "Speaker view" : "Поглед на тој што зборува",
+    "Grid view" : "Мрежа",
     "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
     "Screen sharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
@@ -546,7 +547,6 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
     "Back" : "Назад",
     "Access to camera was denied" : "Нема пристап до камерата",
-    "Error while accessing camera: it is likely in use by another program" : "Грешка при пристап до камера: веројатно е во употреба од друга програма",
     "Error while accessing camera" : "Грешка при пристап до камера",
     "You have been muted by a moderator" : "Администраторот ве занеми",
     "You" : "Ти",
@@ -650,6 +650,7 @@ OC.L10N.register(
     "Add other sources" : "Додади други извори",
     "Participants" : "Учесници",
     "Chat" : "Разговор",
+    "Settings" : "Параметри",
     "Display name: " : "Име:",
     "Attachments folder" : "Папка со прилози",
     "Privacy" : "Приватност",
@@ -660,7 +661,6 @@ OC.L10N.register(
     "Fullscreen the chat or call" : "Цел екран на разговор или повик",
     "Search" : "Барај",
     "Shortcuts while in a call" : "Кратенки за време на повик",
-    "Video on and off" : "Вклучување и исклучување на видеото",
     "Microphone on and off" : "Вклучување и исклучување на микрофонот",
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
@@ -668,8 +668,6 @@ OC.L10N.register(
     "Toggle fullscreen" : "Вклучи на цел екран",
     "Rename conversation" : "Преименувај разговор",
     "Mute others" : "Занеми ги останатите",
-    "Speaker view" : "Поглед на тој што зборува",
-    "Grid view" : "Мрежа",
     "Send" : "Испрати",
     "Add more files" : "Додади повеќе датотеки",
     "No unread mentions" : "Нема непрочитани спомнувања",
@@ -712,25 +710,19 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
     "Android app" : "Android апликација",
     "iOS app" : "iOS апликација",
-    "New in Talk 6" : "Ново во Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Разговорите еден на еден сега се постојани и не можат повеќе случајно да се претвораат во групни разговори. Исто така, кога еден од учесниците го напушта разговорот, разговорот не се брише автоматски. Само ако двајцата учесници заминат, разговорот е избришан од серверот",
-    "New in Talk 7" : "Ново во Talk 7",
-    "New in Talk 8" : "Ново во Talk 8",
-    "New in Talk 9" : "Ново во Talk 9",
-    "New in Talk 10" : "Ново во Talk 10",
+    "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\"",
     "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} постави мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
     "You set up Matterbridge to synchronize this conversation with other chats." : "Поставивте мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
     "{actor} updated the Matterbridge configuration." : "{actor} ја ажурираше конфигурацијата на мостот.",
     "You updated the Matterbridge configuration." : "Ја ажуриравте конфигурацијата на мостот.",
     "{actor} removed the Matterbridge configuration." : "{actor} ја избриша конфигурацијата на мостот.",
     "You removed the Matterbridge configuration." : "Ја избришавте конфигурацијата на мостот.",
-    "{user} wants to talk with you" : "{user} сака да разговара со вас",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Корисниците кој повеќе не користат Talk ќе бидат сеуште учесници во нивните предходни разговори и нивните пораки ќе се чуваат.",
     "E-mail of the user" : "Е-пошта на корисник",
     "Error: Can not connect to server" : "Грешка: Неможе да се поврзе со сервер",
-    "UDP and TCP" : "UDP и TCP",
-    "UDP only" : "Само UDP",
-    "TCP only" : "Само TCP",
     "Share whole screen" : "Сподели го целиот екран",
     "Share a single window" : "Сподели единечен прозор",
     "Mute audio (m)" : "Занеми (Mute) го аудиото (m)",
@@ -740,8 +732,8 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео (v) - Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
     "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат вашиот екран. За да ја подобрите ситуацијата, обидете се да го оневозможите споделувањето екран.",
-    "This conversation is read only" : "Разговорот е само за читање",
-    "Conversation, " : "Разговор,",
+    "Error while accessing camera: it is likely in use by another program" : "Грешка при пристап до камера: веројатно е во употреба од друга програма",
+    "User name or e-mail address" : "Корисничко име или е-пошта адреса",
     "Chat notifications" : "Известувања за разговор",
     "Allow guests to join via link " : "Дозволи им на гостите да се приклучат преку линк",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Моментално чекате во лобито. Состанокот е закажан во {startTime}",
@@ -749,18 +741,9 @@ OC.L10N.register(
     "Camera" : "Камера",
     "Remove" : "Отстрани",
     "[Unknown username]" : "[Непознато корисничко име]",
-    "Bridge with other services" : "Мост со други сервери",
-    "Enabled" : "Овозможен",
-    "User name or e-mail address" : "Корисничко име или е-пошта адреса",
-    "Add participants to the conversation" : "Додадете учесници кон разговорот",
+    "Video on and off" : "Вклучување и исклучување на видеото",
     "Choose in which folder attachments should be saved." : "Изберете во која папка ќе се зачувуваат примероците.",
-    "Share link" : "Сподели линк",
     "Exit fullscreen (f)" : "Излез од цел екран (f)",
-    "Fullscreen (f)" : "Приказ на цел екран (f)",
-    "Error while uploading file" : "Грешка при прикачување на датотека",
-    "Use speaker view" : "Користете поглед кон тој што зборува",
-    "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
-    "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
-    "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\""
+    "Fullscreen (f)" : "Приказ на цел екран (f)"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
