@@ -357,11 +357,10 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
     "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
+    "Dismiss" : "Forkast",
     "Show your screen" : "Vis din skjerm",
     "Stop screensharing" : "Stopp skjermdeling",
     "More actions" : "Flere handlinger",
-    "Settings" : "Innstillinger",
-    "Dismiss" : "Forkast",
     "No audio" : "Ingen lyd",
     "Mute audio" : "Slå av lyd",
     "Unmute audio" : "Slå på lyd",
@@ -370,6 +369,7 @@ OC.L10N.register(
     "Enable video" : "Skru på video",
     "Screensharing options" : "Skjermdelingsvalg",
     "Enable screensharing" : "Skru på skjermdeling",
+    "Grid view" : "Rutenett-visning",
     "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
     "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
@@ -455,11 +455,11 @@ OC.L10N.register(
     "Add users or groups" : "Legg til bruker eller gruppe",
     "Participants" : "Deltakere",
     "Chat" : "Sludre",
+    "Settings" : "Innstillinger",
     "Keyboard shortcuts" : "Tastatursnarveier",
     "Search" : "Søk",
     "Start call" : "Start samtale",
     "Rename conversation" : "Endre navn på samtale",
-    "Grid view" : "Rutenett-visning",
     "Send" : "Send",
     "Start a conversation" : "Start en samtale",
     "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
@@ -478,20 +478,20 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
     "Android app" : "Android-app",
     "iOS app" : "iOS-app",
-    "New in Talk 6" : "Nytt i Talk 6",
-    "New in Talk 7" : "Nytt i Talk 7",
-    "New in Talk 8" : "Nytt i Talk 8",
-    "New in Talk 9" : "Nytt i Talk 9",
-    "New in Talk 10" : "Nytt i Talk 10",
+    "{actor} set the description to \"%1$s\"" : "{actor} satte beskrivelsen til \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Du satte beskrivelsen til \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "En administrator satte beskrivelsen til \"%1$s\"",
     "You updated the Matterbridge configuration." : "Du oppdaterte Matterbridge innstillingene.",
     "You removed the Matterbridge configuration." : "Du fjernet Matterbridge innstillingene.",
-    "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
+    "{actor} started Matterbridge." : "{actor} startet Matterbridge.",
+    "You started Matterbridge." : "Du startet Matterbridge.",
+    "{actor} stopped Matterbridge." : "{actor} stoppet Matterbridge.",
+    "You stopped Matterbridge." : "Du stoppet Matterbridge.",
     "E-mail of the user" : "Brukerens epostadresse",
-    "UDP and TCP" : "UDP og TCP",
-    "UDP only" : "kun UDP",
-    "TCP only" : "kun TCP",
     "Share whole screen" : "Del hele skjermen",
     "Share a single window" : "Del et enkelt vindu",
+    "Lower hand" : "Senk hånden",
+    "Raise hand" : "Løft hånden",
     "Mute audio (m)" : "Slå av lyd (m)",
     "Unmute audio (m)" : "Slå på lyd (m)",
     "Disable video (v)" : "Skru av video (v)",
@@ -499,18 +499,7 @@ OC.L10N.register(
     "Microphone" : "Mikrofon",
     "Camera" : "Kamera",
     "Remove" : "Fjern",
-    "Enabled" : "Aktivert",
-    "Share link" : "Del lenke",
     "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
-    "Fullscreen (f)" : "Fullskjermsvisning (f)",
-    "{actor} set the description to \"%1$s\"" : "{actor} satte beskrivelsen til \"%1$s\"",
-    "You set the description to \"%1$s\"" : "Du satte beskrivelsen til \"%1$s\"",
-    "An administrator set the description to \"%1$s\"" : "En administrator satte beskrivelsen til \"%1$s\"",
-    "{actor} started Matterbridge." : "{actor} startet Matterbridge.",
-    "You started Matterbridge." : "Du startet Matterbridge.",
-    "{actor} stopped Matterbridge." : "{actor} stoppet Matterbridge.",
-    "You stopped Matterbridge." : "Du stoppet Matterbridge.",
-    "Lower hand" : "Senk hånden",
-    "Raise hand" : "Løft hånden"
+    "Fullscreen (f)" : "Fullskjermsvisning (f)"
 },
 "nplurals=2; plural=(n != 1);");
