@@ -480,7 +480,11 @@ OC.L10N.register(
     "Error requesting the password." : "Error en demandant lo senhal.",
     "This conversation has ended" : "La conversacion es acabada",
     "Limit to groups" : "Limitar als grops",
+    "Guests can still join public conversations." : "Los convidats pòdon encara rejónher las conversacions publicas.",
     "Limit using Talk" : "Limits d’utilizacion de Talk",
+    "Limit creating a public and group conversation" : "Limitar la creacion de grops e publicas de conversacions",
+    "Limit creating conversations" : "Limitar la creacion de conversacions",
+    "Limit starting a call" : "Limitar l’aviada de sonada",
     "Everyone" : "Tot lo monde",
     "Users and moderators" : "Utilizaires e moderators",
     "Moderators only" : "Moderators solament",
@@ -502,7 +506,9 @@ OC.L10N.register(
     "General settings" : "Paramètres generals",
     "Default notification settings" : "Paramètres de notificacion per defaut",
     "Default group notification" : "Notificacion de grop per defaut",
+    "Integration into other apps" : "Integracion dins d’autras aplicacions",
     "Allow conversations on files" : "Permetre las conversacions suls fichièrs",
+    "Allow conversations on public shares for files" : "Permetre las conversacions suls partiment de fichièrs",
     "All messages" : "Totes los messatges",
     "@-mentions only" : "@-mencions sonque",
     "Off" : "Atudat",
@@ -537,7 +543,6 @@ OC.L10N.register(
     "OK: Running version: {version}" : "OK : execucion de la version : {version}",
     "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
     "Error: Server did not respond with proper JSON" : "Error: lo servidor a pas respondut amb un JSON corrèct",
-    "Error: Server needs to be updated to be compatible with this version of Talk" : "Error  : lo servidor requerís una actualizacion per èsser compatible amb aquesta version de Talk",
     "Error: Server responded with: {error}" : "Error : lo servidor a respondut : {error}",
     "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
     "Saved" : "Enregistrat",
@@ -555,6 +560,10 @@ OC.L10N.register(
     "{schema} scheme must be used with a domain" : "l’esquèma {schema} deu èsser utilizat amb un domeni",
     "Test this server" : "Ensajar aqueste servidor",
     "TURN servers" : "Servidor TURN",
+    "Web server setup checks" : "Verificacions de configuracion del servidor Web",
+    "Failed" : "Fracàs",
+    "OK" : "D’acòrdi",
+    "Checking …" : "Verificacion…",
     "{nickName} raised their hand." : "{nickName} a levat la man.",
     "A participant raised their hand." : "Un participant a levat la man.",
     "Previous page of videos" : "Pagina de vidèos precedenta",
@@ -562,16 +571,20 @@ OC.L10N.register(
     "Copy link" : "Copiar lo ligam",
     "Connecting …" : "Connexion…",
     "Waiting for others to join the call …" : "En espèra que d’autres arriben…",
+    "You can invite others in the participant tab of the sidebar" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Podètz convidar d’autre monde amb l’onglet dels participants de la barra laterala o partejar aqueste ligam per los convidar !",
     "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
     "Conversation link copied to clipboard." : "Ligam de conversacion copiat al quichapapièrs.",
     "The link could not be copied." : "Impossible de copiar lo ligam.",
+    "Dismiss" : "Regetar",
     "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
     "Lower hand (R)" : "Baissar la man (R)",
     "More actions" : "Mai d’accions",
-    "Settings" : "Paramètres",
-    "Dismiss" : "Regetar",
+    "Devices settings" : "Paramètres dels periferics",
     "Raise hand (R)" : "Levar la man (R)",
+    "Blur background" : "Rèireplan trebol",
+    "Disable background blur" : "Desactivar lo rèireplan trebol",
     "You are not allowed to enable audio" : "Avètz pas l'autorizacion per activar l’àudio",
     "No audio" : "Cap d’àudio",
     "Mute audio (M)" : "Copar lo son (M)",
@@ -591,12 +604,19 @@ OC.L10N.register(
     "Enable screensharing" : "Activar lo partiment d’ecran",
     "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
     "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
     "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo pendent un partiment d’ecran.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas vòstre ecran. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
     "Disable screenshare" : "Desactivar lo partiment d’ecran",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar lo rèireplan o la vidèo.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas.",
+    "Speaker view" : "Vista parlaire",
+    "Grid view" : "Vista en grasilha",
     "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
@@ -606,10 +626,15 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Back" : "Retorn",
     "Access to camera was denied" : "L’accès a la camèra es estat refusat",
-    "Error while accessing camera: it is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utiliza",
+    "Error while accessing camera: It is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utilize",
     "Error while accessing camera" : "Error pendent l’accès a la camèra",
     "You have been muted by a moderator" : "Un moderator vos a amudit",
     "You" : "Vos",
+    "Connection could not be established …" : "Establiment impossible de la connexion…",
+    "Connection was lost and could not be re-established …" : "Connexion perduda e restabliment impossibla…",
+    "Connection could not be established. Trying again …" : "Establiment impossible… Novèl ensag…",
+    "Connection lost. Trying to reconnect …" : "Connexion perduda. Ensag de reconnexion…",
+    "Connection problems …" : "Problèmas de connexion…",
     "Show screen" : "Far veire l’ecran",
     "Mute" : "Mut",
     "Stop following" : "Quitar de seguir",
@@ -629,6 +654,7 @@ OC.L10N.register(
     "Conversation settings" : "Paramètres de conversacion",
     "Description" : "Descripcion",
     "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
+    "Notifications" : "Notificacions",
     "Device check" : "Verificacion de periferic",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Guests access" : "Accès convidat",
@@ -735,6 +761,9 @@ OC.L10N.register(
     "running" : "en cors d'execucion",
     "not running" : "pas en execucion",
     "Bridge saved" : "Pont enregistrat",
+    "Chat messages" : "Messatges",
+    "Calls" : "Sonadas",
+    "Notify about calls in this conversation" : "Notificar las sonadas d’aquesta conversacion",
     "Cancel editing description" : "Anullar la modificacion de la descripcion",
     "Submit conversation description" : "Enviar la descripcion de la conversacion",
     "Edit conversation description" : "Editar la descripcion de la conversacion",
@@ -828,17 +857,21 @@ OC.L10N.register(
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
     "Invalid path selected" : "Camin seleccionat invalid",
+    "Start a call" : "Començar una sonada",
     "Skip the lobby" : "Passar la sala d’espèra",
     "Enable the microphone" : "Activar lo microfòn",
     "Enable the camera" : "Activar la camèra",
     "Share the screen" : "Partejar l’ecran",
     "Update permissions" : "Actualizar las autorizacions",
     "Updating permissions" : "Actualizacion de las permissions",
+    "In this conversation <strong>{user}</strong> can:" : "Dins aquesta conversacion <strong>{user}</strong> pòt :",
     "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modificar las permissions per defaut dels participants dins <strong>{conversationName}</strong>",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "moderator" : "moderator",
     "bot" : "robòt",
     "guest" : "convidat",
+    "Reset custom permissions" : "Reïnicializar las permissions personalizadas",
+    "Remove all permissions" : "Suprimir totas las permissions",
     "Resend invitation" : "Renviar invitacion",
     "Remove group and members" : "Levar de grops e membres",
     "Remove participant" : "Tirar participant",
@@ -851,12 +884,18 @@ OC.L10N.register(
     "Raised their hand" : "Levèt la man",
     "Invitation was sent to {actorId}." : "Invitacion enviada a {actorId}.",
     "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
+    "Permissions granted to {displayName}" : "Autorizacions acordadas a {displayName}",
+    "Permissions removed for {displayName}" : "Permissions suprimidas per {displayName}",
+    "Permissions set to default for {displayName}" : "Permissions definidas a defaut per {displayName}",
+    "Permissions modified for {displayName}" : "Permissions modificadas per {displayName}",
     "Add users" : "Apondre utilizaires",
     "Add groups" : "Apondre grops",
     "Add emails" : "Apondre emails",
     "Add circles" : "Apondre cercles",
+    "Add federated users" : "Apondre d’utilizaires federats",
     "Searching …" : "Recèrca…",
     "No results" : "Pas cap de resultat",
+    "Search for more users" : "Cercar mai d’utilizaires",
     "Add users, groups or circles" : "Apondre utilizaires, grops o cercles",
     "Add users or groups" : "Add users or groups",
     "Add users or circles" : "Apondre utilizaires o cercles",
@@ -865,9 +904,10 @@ OC.L10N.register(
     "Participants" : "Participants",
     "Search or add participants" : "Cercar o apondre participants",
     "An error occurred while adding the participants" : "Una error s’es producha en ajustant los participants",
-    "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
     "Chat" : "Messatjariá",
     "Details" : "Detalhs",
+    "Settings" : "Paramètres",
+    "Participants ({count})" : "Participants ({count})",
     "Meeting ID: {meetingId}" : "ID reünion : {meetingId}",
     "Your PIN: {attendeePin}" : "Vòstre PIN : {attendeePin}",
     "Display name: " : "Nom d’afichatge :",
@@ -881,7 +921,7 @@ OC.L10N.register(
     "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
     "Search" : "Search",
     "Shortcuts while in a call" : "Acorchis pendent una sonada",
-    "Video on and off" : "Vidèo activada/desactivada",
+    "Camera on and off" : "Vidèo activada/desactivada",
     "Microphone on and off" : "Microfòn activat/desactivat",
     "Space bar" : "barra d’espaci",
     "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
@@ -904,8 +944,6 @@ OC.L10N.register(
     "Mute others" : "Copar lo son dels autres",
     "Exit fullscreen (F)" : "Quitar plen ecran (F)",
     "Fullscreen (F)" : "Plen ecran (F)",
-    "Speaker view" : "Vista parlaire",
-    "Grid view" : "Vista en grasilha",
     "You have new unread messages in the chat." : "Avètz un messatge pas legit al chat.",
     "You have been mentioned in the chat." : "Qualqu’un vos a mencionat al chat.",
     "Send" : "Mandar",
@@ -918,10 +956,12 @@ OC.L10N.register(
     "Mention myself" : "Me mencionar",
     "Mention room" : "Mencionar la sala",
     "The conversation does not exist" : "La conversacion existís pas",
+    "Join a conversation or start a new one!" : "Rejonhètz una conversacion o creatz-ne una !",
     "No conversations found" : "Cap de conversacion pas trobada",
     "Select conversation" : "Seleccionar una conversacion",
     "Link to a conversation" : "Ligam cap a la conversacion",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
+    "Join a conversation or start a new one" : "Rejónher una conversacion o ne crear una",
     "Post to a conversation" : "Publicar dins una conversacion",
     "Post to conversation" : "Publicar a la conversacion",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
@@ -930,6 +970,7 @@ OC.L10N.register(
     "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
     "Error while accessing microphone" : "Error pendent l’accès al microfòn",
     "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
+    "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
@@ -938,6 +979,9 @@ OC.L10N.register(
     "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
     "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
+    "Could not post message: {errorMessage}" : "Fracàs de la publicacion : {errorMessage}",
+    "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
+    "Join here" : "Rejónher aquí",
     "Leave this page" : "Quitar aquesta pagina",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
     "Sending signaling message has failed." : "Lo mandadís de messatge de senhalament a pas reüssit.",
@@ -964,63 +1008,49 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Lo servidor TURN es utilizat per desviar lo trafic dels participants darrièr un parafuòc.",
     "Signaling servers" : "Servidors de senhalizacion",
     "%s Talk on your mobile devices" : "%sTalk on vòstres aparelhs mobiles",
+    "Join conversations at any time, anywhere, on any device." : "Participatz a las conversacion quand volètz, d’ont volètz, sus tot aparelh.",
     "Android app" : "Aplicacion Android",
     "iOS app" : "Aplicacion iOS",
-    "New in Talk 6" : "Nòu dins Talk 6",
-    "New in Talk 7" : "Nòu dins Talk 7",
-    "New in Talk 8" : "Nòu dins Talk 8",
-    "New in Talk 9" : "Nòu dins Talk 9",
-    "New in Talk 10" : "Nòu dins Talk 10",
+    "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
+    "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
+    "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
     "{actor} updated the Matterbridge configuration." : "{actor} metèt a jorn la configuracion de Matterbridge",
     "You updated the Matterbridge configuration." : "Avètz mes a jorn la configuracion de Matterbridge",
+    "{actor} removed the Matterbridge configuration." : "{actor} suprimiguèt la configuracion de Matterbridg",
     "You removed the Matterbridge configuration." : "Avètz tirada la configuracion de Matterbridge.",
-    "{user} wants to talk with you" : "{user} vòl vos parlar",
+    "{actor} started Matterbridge." : "{actor} lancèt Matterbridge.",
+    "You started Matterbridge." : "Avètz lançat Matterbridge.",
+    "{actor} stopped Matterbridge." : "{actor} arrestèt Matterbridge.",
+    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
     "E-mail of the user" : "E-mail de l’utilizaire",
     "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
-    "UDP and TCP" : "UDP e TCP",
-    "UDP only" : "Sonque UDP",
-    "TCP only" : "Sonque TCP",
     "Share whole screen" : "Partejar l’ecran complet",
     "Share a single window" : "Partejar sonque una fenèstra",
+    "Lower hand" : "Baissar la man",
+    "Raise hand" : "Levar la man",
     "Mute audio (m)" : "Copar lo son (m)",
     "Unmute audio (m)" : "Restablir lo son (m)",
     "Disable video (v)" : "Desactivar la vidèo (v)",
     "Enable video (v)" : "Activar la vidèo (v)",
     "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
-    "This conversation is read only" : "La conversacion es en lectura sola",
-    "Conversation, " : "Conversacion, ",
+    "Error while accessing camera: it is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utiliza",
+    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
+    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
+    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
     "Chat notifications" : "Notificacions de chat",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
     "Microphone" : "Microfòn",
     "Camera" : "Camèra",
+    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
     "Remove" : "Suprimir",
     "[Unknown username]" : "[utilizaire desconegut]",
-    "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
-    "Enabled" : "Activada",
-    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
-    "Participant settings" : "Paramètres participants",
-    "Add participants to the conversation" : "Apondre participants a la conversacion",
+    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion",
+    "Video on and off" : "Vidèo activada/desactivada",
     "Choose in which folder attachments should be saved." : "Causir dins quin dossièr las pèças juntas devon èsser enregistradas.",
-    "Share link" : "Partejar lo ligam",
     "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
     "Fullscreen (f)" : "Ecran complèt (f)",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
-    "Error while uploading file" : "Error en enviant lo fichièr",
-    "Use speaker view" : "Utilizar la vista de parlaire",
-    "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
-    "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
-    "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
-    "{actor} started Matterbridge." : "{actor} lancèt Matterbridge.",
-    "You started Matterbridge." : "Avètz lançat Matterbridge.",
-    "{actor} stopped Matterbridge." : "{actor} arrestèt Matterbridge.",
-    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
-    "Lower hand" : "Baissar la man",
-    "Raise hand" : "Levar la man",
-    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
-    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
-    "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
-    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion"
+    "Set the notification level for the current conversation. This will affect only the notifications you receive." : "Definir lo nivèl de notificacion per la conversacion actuala. Afectarà sonque las notificacions que recebètz."
 },
 "nplurals=2; plural=(n > 1);");
