@@ -458,6 +458,8 @@ OC.L10N.register(
     "Blocked" : "Blockerar",
     "Active" : "Aktiv",
     "Expired" : "Utgånget",
+    "Downloading …" : "Hämtar …",
+    "Installed version: {version}" : "Installerad version: {version}",
     "Shared secret" : "Delad hemlighet",
     "Validate SSL certificate" : "Validera SSL-certifikat",
     "Delete this server" : "Ta bort denna server",
@@ -474,6 +476,8 @@ OC.L10N.register(
     "STUN server URL" : "STUN-serverwebbadress",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
+    "{option1} and {option2}" : "{option1} och {option2}",
+    "{option} only" : "endast {option}",
     "TURN server URL" : "TURN-serverwebbadress",
     "TURN server secret" : "TURN-server hemlighet",
     "TURN server protocols" : "TURN-server protokoll",
@@ -486,10 +490,9 @@ OC.L10N.register(
     "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
     "Conversation link copied to clipboard." : "Konversationslänk kopierad till urklipp.",
     "The link could not be copied." : "Länken kunde inte kopieras.",
+    "Dismiss" : "Avfärda",
     "Show your screen" : "Visa din skärm",
     "Stop screensharing" : "Stoppa skärmdelning",
-    "Settings" : "Inställningar",
-    "Dismiss" : "Avfärda",
     "No audio" : "Inget ljud",
     "Mute audio" : "Stäng av ljudet",
     "Unmute audio" : "Aktivera ljud",
@@ -499,6 +502,7 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
     "Screensharing options" : "Skärmdelningsalternativ",
     "Enable screensharing" : "Tillåt skärmdelning",
+    "Grid view" : "Rutnätsvy",
     "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
@@ -529,11 +533,22 @@ OC.L10N.register(
     "Start time (optional)" : "Starttid (valfritt)",
     "Save" : "Spara",
     "Edit" : "Ändra",
+    "Nextcloud URL" : "Nextcloud-URL",
+    "Nextcloud user" : "Nextcloud-användare",
+    "Matrix server URL" : "Matrix server-URL",
+    "Matrix channel" : "Matrix-kanal",
+    "Mattermost user" : "Mattermost-användare",
+    "Channel name" : "Kanalnamn",
     "Password" : "Lösenord",
     "API token" : "API-token",
+    "Slack channel" : "Slack-kanal",
+    "Channel ID or name" : "Kanal-id eller namn",
+    "Channel" : "Kanal",
     "Login" : "Logga in",
     "Nickname" : "Smeknamn",
     "Client ID" : "Klient-ID",
+    "Jabber ID" : "Jabber-id",
+    "Bridge saved" : "Brygga sparad",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
     "You: {lastMessage}" : "Du: {lastMessage}",
@@ -594,8 +609,8 @@ OC.L10N.register(
     "Add other sources" : "Lägg till andra källor",
     "Participants" : "Deltagare",
     "Search or add participants" : "Sök eller lägg till deltagare",
-    "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Chat" : "Chat",
+    "Settings" : "Inställningar",
     "Display name: " : "Visningsnamn:",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Search" : "Sök",
@@ -605,7 +620,6 @@ OC.L10N.register(
     "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
     "Toggle fullscreen" : "Växla helskärm",
     "Rename conversation" : "Byt namn på konversation",
-    "Grid view" : "Rutnätsvy",
     "Send" : "Skicka",
     "No unread mentions" : "Inga olästa omnämnanden",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
@@ -618,6 +632,7 @@ OC.L10N.register(
     "Select conversation" : "Välj konversation",
     "Link to a conversation" : "Länka till en konversation",
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
+    "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
     "Do not disturb" : "Stör ej",
     "Away" : "Iväg",
@@ -647,20 +662,14 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
-    "New in Talk 6" : "Nytt i Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
-    "New in Talk 7" : "Nytt i Talk 7",
-    "New in Talk 8" : "Nytt i Talk 8",
-    "New in Talk 9" : "Nytt i Talk 9",
-    "New in Talk 10" : "Nytt i Talk 10",
+    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
+    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
+    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\"",
     "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
     "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
-    "{user} wants to talk with you" : "{user} vill prata med dig",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
     "Error: Can not connect to server" : "Error: Kan inte ansluta till server",
-    "UDP and TCP" : "UDP och TCP",
-    "UDP only" : "endast UDP",
-    "TCP only" : "endast TCP",
     "Share whole screen" : "Dela hela skärmen",
     "Share a single window" : "Dela ett fönster",
     "Mute audio (m)" : "Ljud av (m)",
@@ -668,24 +677,13 @@ OC.L10N.register(
     "Disable video (v)" : "Inaktivera video (v)",
     "Enable video (v)" : "Aktivera video (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (v) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
-    "This conversation is read only" : "Denna konversation är skrivskyddad",
-    "Conversation, " : "Konversation, ",
     "Chat notifications" : "Chatt-aviseringar",
     "Allow guests to join via link " : "Tillåt gäster att ansluta via länk",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "Camera" : "Kamera",
     "Remove" : "Ta bort",
     "[Unknown username]" : "[Okänt användarnamn]",
-    "Enabled" : "Aktiverad",
-    "Participant settings" : "Deltagarinställningar",
-    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
-    "Share link" : "Dela länk",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
-    "Fullscreen (f)" : "Fullskärm (f)",
-    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
-    "Error while uploading file" : "Fel vid uppladdning av fil",
-    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
-    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
-    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\""
+    "Fullscreen (f)" : "Fullskärm (f)"
 },
 "nplurals=2; plural=(n != 1);");
