@@ -30,11 +30,11 @@ use OCA\Talk\Config;
 use OCA\Talk\Events\AddParticipantsEvent;
 use OCA\Talk\Events\AttendeesAddedEvent;
 use OCA\Talk\Events\AttendeesRemovedEvent;
+use OCA\Talk\Events\EndCallForEveryoneEvent;
 use OCA\Talk\Events\JoinRoomGuestEvent;
 use OCA\Talk\Events\JoinRoomUserEvent;
 use OCA\Talk\Events\ModifyEveryoneEvent;
 use OCA\Talk\Events\ModifyParticipantEvent;
-use OCA\Talk\Events\ModifyRoomEvent;
 use OCA\Talk\Events\ParticipantEvent;
 use OCA\Talk\Events\RemoveParticipantEvent;
 use OCA\Talk\Events\RemoveUserEvent;
@@ -260,17 +260,16 @@ class ParticipantService {
 		try {
 			$attendee = $this->attendeeMapper->findByActor($room->getId(), Attendee::ACTOR_USERS, $user->getUID());
 		} catch (DoesNotExistException $e) {
-			if (!$event->getPassedPasswordProtection() && !$room->verifyPassword($password)['result']) {
+			// queried here to avoid loop deps
+			$manager = \OC::$server->get(\OCA\Talk\Manager::class);
+			$isListableByUser = $manager->isRoomListableByUser($room, $user->getUID());
+
+			if (!$isListableByUser && !$event->getPassedPasswordProtection() && !$room->verifyPassword($password)['result']) {
 				throw new InvalidPasswordException('Provided password is invalid');
 			}
 
-			// queried here to avoid loop deps
-			$manager = \OC::$server->get(\OCA\Talk\Manager::class);
-
 			// User joining a group or public call through listing
-			if (($room->getType() === Room::TYPE_GROUP || $room->getType() === Room::TYPE_PUBLIC) &&
-				$manager->isRoomListableByUser($room, $user->getUID())
-			) {
+			if (($room->getType() === Room::TYPE_GROUP || $room->getType() === Room::TYPE_PUBLIC) && $isListableByUser) {
 				$this->addUsers($room, [[
 					'actorType' => Attendee::ACTOR_USERS,
 					'actorId' => $user->getUID(),
@@ -909,16 +908,20 @@ class ParticipantService {
 	}
 
 	public function endCallForEveryone(Room $room, Participant $moderator): void {
-		$event = new ModifyRoomEvent($room, 'in_call', Participant::FLAG_DISCONNECTED, null, $moderator);
+		$event = new EndCallForEveryoneEvent($room, $moderator);
 		$this->dispatcher->dispatch(Room::EVENT_BEFORE_END_CALL_FOR_EVERYONE, $event);
 
 		$participants = $this->getParticipantsInCall($room);
+		$changedSessionIds = [];
 
 		// kick out all participants out of the call
 		foreach ($participants as $participant) {
+			$changedSessionIds[] = $participant->getSession()->getSessionId();
 			$this->changeInCall($room, $participant, Participant::FLAG_DISCONNECTED, true);
 		}
 
+		$event->setSessionIds($changedSessionIds);
+
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_END_CALL_FOR_EVERYONE, $event);
 	}
 
